@@ -21,18 +21,18 @@
  *    Chema Celorio <chema@celorio.com>
  *    Tambet Ingo <tambet@ximian.com>
  *
- *  Copyright (C) 2000-2001 Ximian, Inc.
- *
+ *  Copyright (C) 2000-2003 Ximian, Inc.
  */
 
 /* TODO: Recycle font entries, if they are identical for different maps */
 
-#include "config.h"
+#include <config.h>
 #include <time.h>
 #include <stdlib.h>
 #include <string.h>
+
 #include <fontconfig/fontconfig.h>
-#include "gnome-fontmap.h"
+#include <libgnomeprint/gnome-fontmap.h>
 
 static GPFontMap *gp_fontmap_load (void);
 
@@ -50,6 +50,8 @@ static GHashTable * fontlist2map = NULL;
 /* Familylist -> FontMap */
 static GHashTable * familylist2map = NULL;
 
+#define my_g_free(x) if(x)g_free(x)
+
 GPFontMap *
 gp_fontmap_get (void)
 {
@@ -57,9 +59,8 @@ gp_fontmap_get (void)
 	static time_t lastaccess = 0;
 
 	if (map) {
-		/* If > 1 sec is passed from last query, check timestamps */
+		/* If > 1 sec is passed reload the fontmap */
 		if ((time (NULL) > lastaccess)) {
-			/* Any directory is changed, so force rereading of map */
 			gp_fontmap_release (map);
 			map = NULL;
 		}
@@ -69,7 +70,6 @@ gp_fontmap_get (void)
 		map = gp_fontmap_load ();
 	}
 
-	/* Save acess time */
 	lastaccess = time (NULL);
 
 	map->refcount++;
@@ -97,8 +97,10 @@ gp_fontmap_unref (GPFontMap * map)
 	g_return_if_fail (map != NULL);
 
 	if (--map->refcount < 1) {
-		if (map->familydict) g_hash_table_destroy (map->familydict);
-		if (map->fontdict) g_hash_table_destroy (map->fontdict);
+		if (map->familydict)
+			g_hash_table_destroy (map->familydict);
+		if (map->fontdict)
+			g_hash_table_destroy (map->fontdict);
 		if (map->familylist) {
 			g_hash_table_remove (familylist2map, map->familylist);
 			g_list_free (map->familylist);
@@ -115,16 +117,6 @@ gp_fontmap_unref (GPFontMap * map)
 			gp_font_entry_unref ((GPFontEntry *) map->fonts->data);
 			map->fonts = g_slist_remove (map->fonts, map->fonts->data);
 		}
-		while (map->defaults) {
-			GSList *l;
-			l = map->defaults->data;
-			map->defaults = g_slist_remove (map->defaults, l);
-			while (l) {
-				g_free (l->data);
-				l = g_slist_remove (l, l->data);
-			}
-		}
-		if (map->defaultsdict) g_hash_table_destroy (map->defaultsdict);
 		g_free (map);
 	}
 }
@@ -139,8 +131,10 @@ static void
 gp_family_entry_unref (GPFamilyEntry * entry)
 {
 	if (--entry->refcount < 1) {
-		if (entry->name) g_free (entry->name);
-		if (entry->fonts) g_slist_free (entry->fonts);
+		if (entry->name)
+			g_free (entry->name);
+		if (entry->fonts)
+			g_slist_free (entry->fonts);
 		g_free (entry);
 	}
 }
@@ -166,36 +160,43 @@ static GPFontEntry *
 fcpattern_to_gp_font_entry (FcPattern *font)
 {
 	GPFontEntryType font_type = GP_FONT_ENTRY_UNKNOWN;
-	GPFontEntryTT *tt;
-	GPFontEntryT1 *t1;
-	GPFontEntry *e;
+	GPFontEntry *e = NULL;
 	FcResult result;
 	FcChar8 *fc_family, *fc_style, *fc_file;
 	int italic_angle, weight;
+	gboolean outline;
 	gchar *c;
 
-	/* Get Family, Style & Filename */
+	result = FcPatternGetBool (font, FC_OUTLINE, 0, &outline);
+	if (!outline)
+		/* We only care about outline fonts */
+		return NULL;
+
 	result = FcPatternGetString (font, FC_FAMILY, 0, &fc_family);
 	if (result != FcResultMatch || fc_family == NULL) {
-		g_warning ("Can't create GPFontEntry because we could not get a FC_FAMILY for the font\n");
+		g_warning ("Can't create GPFontEntry, FC_FAMILY not found\n");
 		return NULL;
 	}
+
 	result = FcPatternGetString (font, FC_STYLE, 0, &fc_style);
 	if (result != FcResultMatch || fc_style == NULL) {
-		g_warning ("Can't create GPFontEntry for %s because we could not get its FC_STYLE\n",
-			   fc_family);
+		g_warning ("Can't create GPFontEntry for %s, FC_STYLE not found\n", fc_family);
 		return NULL;
 	}
+
 	result = FcPatternGetString (font, FC_FILE, 0, &fc_file);
 	if (result != FcResultMatch || fc_file == NULL) {
-		g_warning ("Can't create GPFontEntry for %s-%s because we could not get its FC_FILE\n",
-			   fc_family, fc_style);
+		g_warning ("Can't create GPFontEntry for %s-%s, FC_FILE not found\n", fc_family, fc_style);
 		return NULL;
 	}
+
 	italic_angle = 0;
 	FcPatternGetInteger (font, FC_SLANT, 0, &italic_angle);
 
-	/* Determine what type of font we've got */
+	/* Determining the font type based on the extension is not very clean, pango uses
+	 *     strcmp (FT_MODULE_CLASS (face->driver)->module_name, "truetype") == 0;
+	 * which isn't prety either (Chema)
+ 	 */
 	c = fc_file + strlen (fc_file) - 4;
 	if (strcasecmp (c, ".pfb") == 0)
 		font_type = GP_FONT_ENTRY_TYPE1;
@@ -203,40 +204,18 @@ fcpattern_to_gp_font_entry (FcPattern *font)
 		font_type = GP_FONT_ENTRY_TYPE1;
 	else if (strcasecmp (c, ".ttf") == 0)
 		font_type = GP_FONT_ENTRY_TRUETYPE;
-	else {
+	else
 		return NULL;
-		g_warning ("Can't create GPFontEntry for %s-%s because the extension could not be recognized (%s)\n",
-			   fc_family, fc_style, c);
-		return NULL;
-	}
 
-	switch (font_type) {
-	case GP_FONT_ENTRY_TRUETYPE:
-		tt = g_new0 (GPFontEntryTT, 1);
-		e = (GPFontEntry *) tt;
-		e->type = GP_FONT_ENTRY_TRUETYPE;
-		tt->ttf.name = g_strdup (fc_file);
-		tt->facenum = 0; /* FIMXE: Is this correct? (Chema) */
-		break;
-	case GP_FONT_ENTRY_TYPE1:
-		t1 = g_new0 (GPFontEntryT1, 1);
-		e = (GPFontEntry *) t1;
-		e->type = GP_FONT_ENTRY_TYPE1;
-		t1->pfb.name = g_strdup (fc_file);
-		t1->afm.name = NULL;
-		break;
-	default:
-		g_warning ("Can't create GPFontEntry, invalid font_type)\n");
-		return NULL;
-	}
-
-	e->refcount = 1;
-	e->face = NULL;
-	e->speciesname = g_strdup (fc_style);
-	e->weight = g_strdup (fc_style);
-	e->familyname = g_strdup (fc_family);
-	e->version = g_strdup ("1.0"); /* FIMXE: Is this correct? (Chema) */
-	e->name    = g_strdup_printf ("%s %s", e->familyname, e->weight);
+	e = g_new0 (GPFontEntry, 1);
+	e->type         = font_type;
+	e->file         = g_strdup (fc_file);
+	e->refcount     = 1;
+	e->face         = NULL;
+	e->speciesname  = g_strdup (fc_style);
+	e->weight       = g_strdup (fc_style);
+	e->familyname   = g_strdup (fc_family);
+	e->name         = g_strdup_printf ("%s %s", e->familyname, e->weight);
 	e->italic_angle = italic_angle;
 	
 	result = FcPatternGetInteger (font, FC_WEIGHT, 0, &weight);
@@ -266,13 +245,9 @@ fcpattern_to_gp_font_entry_alias (FcPattern *font, const gchar *family, const gc
 	if (e == NULL)
 		return NULL;
 
-	/* Override font name and style */
-	if (e->name)
-		g_free (e->name);
-	if (e->psname)
-		g_free (e->psname);
-
-	e->name = g_strdup_printf ("%s %s", family, style);
+	my_g_free (e->name);
+	my_g_free (e->psname);
+	e->name   = g_strdup_printf ("%s %s", family, style);
 	e->psname = g_strdup_printf ("%s-%s", family, style);
 
 	c = e->psname;
@@ -334,8 +309,10 @@ gp_fontmap_add_aliases (GPFontMap *map)
  * @map: 
  * 
  * This function makes sure that the e->psname is unique for each font
- * it appends a dash + 3 digits if it find a duplicate. It grows exponentially which
- * might be a problem for system with a lot of fonts.
+ * it appends a dash + 3 digits if it find a duplicate. It grows
+ * exponentially which might be a problem for system with a lot of fonts.
+ *
+ * FIXME: use a hash to speed it up (Chema)
  **/
 static void
 gp_fontmap_check_duplicates (GPFontMap *map)
@@ -386,9 +363,6 @@ gp_fontmap_load_fontconfig (GPFontMap *map)
 			map->fonts = g_slist_prepend (map->fonts, e);
 		}
 	}
-
-	gp_fontmap_add_aliases (map);
-	gp_fontmap_check_duplicates (map);
 }
 
 static GPFontMap *
@@ -397,24 +371,16 @@ gp_fontmap_load (void)
 	GPFontMap *map;
 	GSList * l;
 
-	map = g_new (GPFontMap, 1);
+	map = g_new0 (GPFontMap, 1);
 	/* We always hold private ref to fontmap, this is released if directories change */
 	map->refcount = 1;
 	map->num_fonts = 0;
-	/* Clear timestamps */
-	map->mtime_static = 0;
-	map->mtime_dynamic = 0;
-	map->mtime_user = 0;
-	map->fontdict = g_hash_table_new (g_str_hash, g_str_equal);
-	map->familydict = g_hash_table_new (g_str_hash, g_str_equal);
-	map->fonts = NULL;
-	map->families = NULL;
-	map->fontlist = NULL;
-	map->familylist = NULL;
-	map->defaults = NULL;
-	map->defaultsdict = g_hash_table_new (g_str_hash, g_str_equal);
+	map->fontdict     = g_hash_table_new (g_str_hash, g_str_equal);
+	map->familydict   = g_hash_table_new (g_str_hash, g_str_equal);
 
 	gp_fontmap_load_fontconfig (map);
+	gp_fontmap_add_aliases (map);
+	gp_fontmap_check_duplicates (map);
 
 	/* Sort fonts alphabetically */
 	map->fonts = g_slist_sort (map->fonts, gp_fe_sortname);
@@ -447,74 +413,20 @@ gp_fontmap_load (void)
 		f->fonts = g_slist_sort (f->fonts, gp_fe_sortspecies);
 	}
 
-	/* Compose defaultsdict */
-	map->defaults = g_slist_reverse (map->defaults);
-	while (map->defaults) {
-		GSList *l;
-		guchar *locales, *fontname;
-		GPFontEntry *entry;
-		l = map->defaults->data;
-		map->defaults = g_slist_remove (map->defaults, l);
-		locales = l->data;
-		fontname = l->next->data;
-		g_slist_free (l);
-		entry = g_hash_table_lookup (map->fontdict, fontname);
-		if (!entry) {
-			GPFamilyEntry *fe;
-			/* Try family */
-			fe = g_hash_table_lookup (map->familydict, fontname);
-			if (fe && fe->fonts) {
-				entry = (GPFontEntry *) fe->fonts->data;
-				l = fe->fonts;
-				while (l) {
-					GPFontEntry *e;
-					e = (GPFontEntry *) l->data;
-					if (!strcasecmp (e->speciesname, "regular") ||
-					    !strcasecmp (e->speciesname, "roman") ||
-					    !strcasecmp (e->speciesname, "normal")) {
-						entry = e;
-						break;
-					}
-					l = l->next;
-				}
-			}
-		}
-		if (entry) {
-			guchar *l;
-			l = locales;
-			while (l) {
-				guchar *e;
-				e = strchr (l, ',');
-				if (e) {
-					*e = '\0';
-					e += 1;
-				}
-				if (!g_hash_table_lookup (map->defaultsdict, l)) {
-					GQuark q;
-					q = g_quark_from_string (l);
-					g_hash_table_insert (map->defaultsdict, (gpointer) g_quark_to_string (q), entry);
-				}
-				l = e;
-			}
-		}
-		g_free (locales);
-		g_free (fontname);
-	}
-
 	return map;
 }
 
 /*
  * Font Entry stuff
  *
- * If face is created, it has to reference entry
+ * If face is created, it has to reference an entry
  */
 
 void
 gp_font_entry_ref (GPFontEntry * entry)
 {
 	g_return_if_fail (entry != NULL);
-	/* refcount can be 1 or 2 at moment */
+	/* refcount can be 1 or 2 at this moment */
 	g_return_if_fail (entry->refcount > 0);
 	g_return_if_fail (entry->refcount < 2);
 
@@ -525,63 +437,19 @@ void
 gp_font_entry_unref (GPFontEntry * entry)
 {
 	g_return_if_fail (entry != NULL);
-	/* refcount can be 1 or 2 at moment */
+	/* refcount can be 1 or 2 at this moment */
 	g_return_if_fail (entry->refcount > 0);
 	g_return_if_fail (entry->refcount < 3);
 
 	if (--entry->refcount < 1) {
-		GPFontEntryT1 *t1;
-		GPFontEntryT1Alias *t1a;
-		GPFontEntrySpecial *s;
-		GPFontEntryTT *tt;
-
 		g_return_if_fail (entry->face == NULL);
 
-		if (entry->name)
-			g_free (entry->name);
-		if (entry->version)
-			g_free (entry->version);
-		if (entry->familyname)
-			g_free (entry->familyname);
-		if (entry->speciesname)
-			g_free (entry->speciesname);
-		if (entry->psname)
-			g_free (entry->psname);
-		if (entry->weight)
-			g_free (entry->weight);
-
-		switch (entry->type) {
-		case GP_FONT_ENTRY_TYPE1_ALIAS:
-			t1a = (GPFontEntryT1Alias *) entry;
-			if (t1a->alias)
-				g_free (t1a->alias);
-		case GP_FONT_ENTRY_TYPE1:
-			t1 = (GPFontEntryT1 *) entry;
-			if (t1->afm.name)
-				g_free (t1->afm.name);
-			if (t1->pfb.name)
-				g_free (t1->pfb.name);
-			break;
-		case GP_FONT_ENTRY_ALIAS:
-			break;
-		case GP_FONT_ENTRY_TRUETYPE:
-			tt = (GPFontEntryTT *) entry;
-			if (tt->ttf.name)
-				g_free (tt->ttf.name);
-			break;
-		case GP_FONT_ENTRY_SPECIAL:
-			s = (GPFontEntrySpecial *) entry;
-			if (s->file.name)
-				g_free (s->file.name);
-			while (s->additional) {
-				g_free (s->additional->data);
-				s->additional = g_slist_remove (s->additional, s->additional->data);
-			}
-			break;
-		default:
-			g_assert_not_reached ();
-			break;
-		}
+		my_g_free (entry->name);
+		my_g_free (entry->familyname);
+		my_g_free (entry->speciesname);
+		my_g_free (entry->psname);
+		my_g_free (entry->weight);
+		my_g_free (entry->file);
 		g_free (entry);
 	}
 }
