@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  gnome-print-config.c: And frontend abstraction to whatever config system we eventually have
+ *  gnome-print-config.h: And frontend abstraction to whatever config system we eventually have
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -18,9 +18,9 @@
  *
  *  Authors:
  *    Lauris Kaplinski <lauris@helixcode.com>
+ *    Chema Celorio <chema@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc.
- *
+ *  Copyright 2001-2003 Ximian, Inc.
  */
 
 #ifndef __GNOME_PRINT_CONFIG_H__
@@ -43,7 +43,7 @@
  * along with this library; see the file COPYING.LIB.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- *
+*
  * Authors:
  *   Lauris Kaplinski <lauris@helixcode.com>
  *
@@ -137,13 +137,16 @@ typedef struct _GnomePrintConfig GnomePrintConfig;
 
 #define GNOME_TYPE_PRINT_CONFIG (gnome_print_config_get_type ())
 
-GnomePrintConfig *gnome_print_config_default (void);
-
 GType gnome_print_config_get_type (void);
 
-GnomePrintConfig *gnome_print_config_ref (GnomePrintConfig *config);
+GnomePrintConfig *gnome_print_config_default (void);
+
+GnomePrintConfig *gnome_print_config_ref   (GnomePrintConfig *config);
 GnomePrintConfig *gnome_print_config_unref (GnomePrintConfig *config);
-GnomePrintConfig *gnome_print_config_dup (GnomePrintConfig *config);
+GnomePrintConfig *gnome_print_config_dup   (GnomePrintConfig *config);
+
+gchar *           gnome_print_config_to_string (GnomePrintConfig *gpc, guint flags);
+GnomePrintConfig *gnome_print_config_from_string (const gchar *str, guint flags);
 
 /*
  * Get/Set key value pairs
@@ -153,29 +156,24 @@ GnomePrintConfig *gnome_print_config_dup (GnomePrintConfig *config);
  * gnome_print_config_get just returns NULL, if given key does not exist.
  *
  */
-
-guchar  *gnome_print_config_get (GnomePrintConfig *config, const guchar *key);
-gboolean gnome_print_config_set (GnomePrintConfig *config, const guchar *key, const guchar *value);
+guchar  *gnome_print_config_get         (GnomePrintConfig *config, const guchar *key);
+gboolean gnome_print_config_set         (GnomePrintConfig *config, const guchar *key, const guchar *value);
 
 gboolean gnome_print_config_get_boolean (GnomePrintConfig *config, const guchar *key, gboolean *val);
-gboolean gnome_print_config_get_int (GnomePrintConfig *config, const guchar *key, gint *val);
-gboolean gnome_print_config_get_double (GnomePrintConfig *config, const guchar *key, gdouble *val);
-gboolean gnome_print_config_get_length (GnomePrintConfig *config, const guchar *key, gdouble *val, const GnomePrintUnit **unit);
+gboolean gnome_print_config_get_int     (GnomePrintConfig *config, const guchar *key, gint *val);
+gboolean gnome_print_config_get_double  (GnomePrintConfig *config, const guchar *key, gdouble *val);
+gboolean gnome_print_config_get_length  (GnomePrintConfig *config, const guchar *key, gdouble *val, const GnomePrintUnit **unit);
 
 gboolean gnome_print_config_set_boolean (GnomePrintConfig *config, const guchar *key, gboolean val);
-gboolean gnome_print_config_set_int (GnomePrintConfig *config, const guchar *key, gint val);
-gboolean gnome_print_config_set_double (GnomePrintConfig *config, const guchar *key, gdouble val);
-gboolean gnome_print_config_set_length (GnomePrintConfig *config, const guchar *key, gdouble val, const GnomePrintUnit *unit);
+gboolean gnome_print_config_set_int     (GnomePrintConfig *config, const guchar *key, gint val);
+gboolean gnome_print_config_set_double  (GnomePrintConfig *config, const guchar *key, gdouble val);
+gboolean gnome_print_config_set_length  (GnomePrintConfig *config, const guchar *key, gdouble val, const GnomePrintUnit *unit);
 
 /*
  * Debugging
  */
-
 void gnome_print_config_dump (GnomePrintConfig *gpc);
 
-/*
- * Convenience keys
- */
 
 /*
  * Paper size
@@ -186,6 +184,9 @@ void gnome_print_config_dump (GnomePrintConfig *gpc);
  *
  */
 
+/*
+ * Convenience keys
+ */
 #define GNOME_PRINT_KEY_PAPER_SIZE               "Settings.Output.Media.PhysicalSize" /* Paper name, such as A4 or Letter */
 #define GNOME_PRINT_KEY_PAPER_WIDTH              "Settings.Output.Media.PhysicalSize.Width" /* Arbitrary units - use conversion */
 #define GNOME_PRINT_KEY_PAPER_HEIGHT             "Settings.Output.Media.PhysicalSize.Height" /* Arbitrary units - use conversion */
@@ -230,15 +231,10 @@ void gnome_print_config_dump (GnomePrintConfig *gpc);
 
 /* More handy keys */
 #define GNOME_PRINT_KEY_OUTPUT_FILENAME "Settings.Transport.Backend.FileName" /* Filename used when printing to file. */
-#define GNOME_PRINT_KEY_DOCUMENT_NAME "Settings.Document.Name"                /* The name of the document 'Cash flow 2002', `Grandma cockie recipies' */
+#define GNOME_PRINT_KEY_DOCUMENT_NAME "Settings.Document.Name"                /* The name of the document 'Cash flow 2002', `Grandma cookie recipies' */
 #define GNOME_PRINT_KEY_PREFERED_UNIT "Settings.Document.PreferedUnit"        /* Abbreviation for the preferred unit cm, in,... */
 
 G_END_DECLS
 
-#endif
-
-
-
-
-
+#endif /* __GNOME_PRINT_CONFIG_H__ */
 
