@@ -20,10 +20,10 @@
  *    Michael Zucchi <notzed@ximian.com>
  *    Lauris Kaplinski <lauris@ximian.com>
  *
- *  Copyright (C) 2000-2001 Ximian Inc.
+ *  Copyright (C) 2000-2003 Ximian Inc.
  */
 
-#include "config.h"
+#include <config.h>
 #include <math.h>
 #include <string.h>
 #include <stdlib.h>
@@ -31,16 +31,12 @@
 #include <locale.h>
 
 #include <libart_lgpl/art_affine.h>
-
-#include <gpa/gpa-node.h>
-
-#include "gnome-print-private.h"
-#include "gnome-print-meta.h"
-#include "gnome-print-multipage.h"
-#include "gnome-print-job-private.h"
-#include "gnome-print-config-private.h"
-
-#define noJOB_VERBOSE
+#include <libgnomeprint/gpa/gpa-node.h>
+#include <libgnomeprint/gnome-print-private.h>
+#include <libgnomeprint/gnome-print-meta.h>
+#include <libgnomeprint/gnome-print-multipage.h>
+#include <libgnomeprint/gnome-print-job-private.h>
+#include <libgnomeprint/gnome-print-config-private.h>
 
 typedef struct _JOBPrivate JOBPrivate;
 
@@ -146,14 +142,12 @@ gnome_print_job_finalize (GObject *object)
 
 /**
  * gnome_print_job_new:
- * @config: The options & settings for this job
+ * @config: The job options, can be NULL in which case a
+ *          default GnomePrintConfig is created
  * 
- * Create a new GnomePrintJob based on the values in the
- * %GnomePrintDialog.  Range values are initialised to sensible
- * defaults.  Other values are initialised from the given dialog.
- * Pass NULL to get have default default values.
+ * Creates a new GnomePrintJob.
  * 
- * Return value: A new GnomePrintJob.
+ * Return value: A new GnomePrintJob, NULL on error
  **/
 GnomePrintJob *
 gnome_print_job_new (GnomePrintConfig *config)
@@ -170,6 +164,14 @@ gnome_print_job_new (GnomePrintConfig *config)
 	return job;
 }
 
+/**
+ * gnome_print_job_get_config:
+ * @job: 
+ * 
+ * Gets a referenced pointer to the configuration of the job
+ * 
+ * Return Value: a referenced GnomePrintConfig for this job, NULL on error
+ **/
 GnomePrintConfig *
 gnome_print_job_get_config (GnomePrintJob *job)
 {
@@ -189,9 +191,8 @@ gnome_print_job_get_config (GnomePrintJob *job)
  * Retrieve the GnomePrintContext which applications
  * print to.
  * 
- * Return value: The printing context.
+ * Return value: The printing context, NULL on error
  **/
-
 GnomePrintContext *
 gnome_print_job_get_context (GnomePrintJob *job)
 {
@@ -209,12 +210,12 @@ gnome_print_job_get_context (GnomePrintJob *job)
  * @job: An initialised and closed GnomePrintJob.
  * 
  * Find the number of pages stored in a completed printout.
+ * This is the number of physical pages, so if the layout
+ * can hold 4 pages per page, and 5 logical pages are printed
+ * (5 beginpage/endpage convinations) 2 is returned 
  * 
- * Return value: If @job has not been closed using
- * gnome_print_job_close(), then 0, otherwise the number
- * of pages created by the application.
+ * Return value: the number of pages, 0 on error
  **/
-
 int
 gnome_print_job_get_pages (GnomePrintJob *job)
 {
@@ -229,21 +230,29 @@ gnome_print_job_get_pages (GnomePrintJob *job)
 
 	job_update_layout_data (job);
 
-	pp = job->priv;
-
 	mp = gnome_print_meta_get_pages (GNOME_PRINT_META (job->meta));
 
+	pp = job->priv;
+
 	if (pp->num_affines <= 1)
 		return mp;
 
 	return (mp + pp->num_affines - 1) / pp->num_affines;
 }
 
-/* fixme: (Lauris) */
-
-/* Get imaging area size available to application (TRUE sucess, FALSE error) */
-/* This takes config for argument, as you may not want to create job yet */
-/* Sizes are given in PS points (GNOME_PRINT_PS_UNIT) */
+/**
+ * gnome_print_job_get_page_size_from_config:
+ * @config: 
+ * @width: 
+ * @height: 
+ * 
+ * Get imaging area size available to application (TRUE sucess,
+ * FALSE error). It takes a config for argument, as you may not
+ * want to create the job yet. Sizes are given in PS points
+ * (GNOME_PRINT_PS_UNIT)
+ * 
+ * Return Value: TRUE on success, FALSE on error
+ **/
 gboolean
 gnome_print_job_get_page_size_from_config (GnomePrintConfig *config, gdouble *width, gdouble *height)
 {
@@ -278,7 +287,9 @@ gnome_print_job_get_page_size_from_config (GnomePrintConfig *config, gdouble *wi
  * gnome_print_job_close:
  * @job: A GnomePrintJob which has had printing performed
  * 
- *  * Closes the GnomePrintJob @job, ready for printing or previewing.
+ * Closes the GnomePrintJob @job, ready for printing or
+ * previewing. To be called after the application has finished
+ * sending the drawing commands
  * 
  * Return Value: 
  **/
@@ -304,17 +315,13 @@ gnome_print_job_close (GnomePrintJob *job)
 
 /**
  * gnome_print_job_print:
- * @job: A completed GnomePrintJob.
+ * @job: A closed GnomePrintJob.
  * 
  * Print the pages stored in the GnomePrintJob to
  * the phyisical printing device.
  *
- * If no printer has been set, then a dialogue is presented,
- * asking the user for the printer to print to.
- * 
- * Return value: Returns -1 on error.
+ * Return value: GNOME_PRINT_OK on success GNOME_PRINT_ERROR_UNKNOWN otherwise
  **/
-
 gint
 gnome_print_job_print (GnomePrintJob *job)
 {
@@ -375,7 +382,7 @@ gnome_print_job_print (GnomePrintJob *job)
 		nsheets = copies;
 	}
 	
-	buf = gnome_print_meta_get_buffer (GNOME_PRINT_META (job->meta));
+	buf  = gnome_print_meta_get_buffer (GNOME_PRINT_META (job->meta));
 	blen = gnome_print_meta_get_length (GNOME_PRINT_META (job->meta));
 
 	for (stack = 0; stack < nstacks; stack++) {
@@ -404,7 +411,17 @@ gnome_print_job_print (GnomePrintJob *job)
 	return ret;
 }
 
-/* Renders printout to specified context */
+
+/**
+ * gnome_print_job_render:
+ * @job: 
+ * @ctx: 
+ * 
+ * Renders printout to specified context
+ * (with layout, ignoring copies)
+ * 
+ * Return Value: 
+ **/
 gint
 gnome_print_job_render (GnomePrintJob *job, GnomePrintContext *ctx)
 {
@@ -440,7 +457,17 @@ gnome_print_job_render (GnomePrintJob *job, GnomePrintContext *ctx)
 	return ret;
 }
 
-/* Renders specified page */
+/**
+ * gnome_print_job_render_page:
+ * @job: 
+ * @ctx: 
+ * @page: 
+ * @pageops: 
+ * 
+ * Renders the specified page @page
+ * 
+ * Return Value: 
+ **/
 gint
 gnome_print_job_render_page (GnomePrintJob *job, GnomePrintContext *ctx, gint page, gboolean pageops)
 {
@@ -467,8 +494,8 @@ gnome_print_job_render_page (GnomePrintJob *job, GnomePrintContext *ctx, gint pa
 	if (pp->LY_LIST) {
 		GnomePrintContext *meta, *mp;
 		gint start, p;
-		/* Create local meta */
-		meta = gnome_print_meta_new_local ();
+
+		meta = gnome_print_meta_new ();
 		g_return_val_if_fail (meta != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 		/* Create wrapper multipage */
 		mp = gnome_print_multipage_new (meta, pp->LY_LIST);
@@ -1063,7 +1090,7 @@ job_parse_transform (guchar *str, gdouble *transform)
  * @gmp: job
  * @output: output file, if NULL sets print to file to FALSE
  * 
- * Sets/unsets the print to file option of the job 
+ * Sets/unsets the print to file option for the job 
  * 
  * Return Value: 
  **/
