@@ -20,15 +20,13 @@
  *    Miguel de Icaza <miguel@gnu.org>
  *    Lauris Kaplinski <lauris@ximian.com>
  *
- *  Copyright (C) 2000-2001 Ximian Inc. and authors
- *
+ *  Copyright (C) 2000-2003 Ximian Inc.
  */
 
-#define __GNOME_PRINT_RGBP_C__
-
-#include "config.h"
+#include <config.h>
 #include <string.h>
 #include <math.h>
+
 #include <libart_lgpl/art_rect.h>
 #include <libgnomeprint/gnome-print-private.h>
 #include <libgnomeprint/gp-gc-private.h>
@@ -138,7 +136,7 @@ rgbp_beginpage (GnomePrintContext *pc, const guchar *name)
 	rgbp = GNOME_PRINT_RGBP (pc);
 	g_return_val_if_fail (rgbp->meta == NULL, GNOME_PRINT_ERROR_UNKNOWN);
 
-	rgbp->meta = (GnomePrintContext *) gnome_print_meta_new_local ();
+	rgbp->meta = (GnomePrintContext *) gnome_print_meta_new ();
 	gnome_print_beginpage (rgbp->meta, name);
 
 	return GNOME_PRINT_OK;
