@@ -20,15 +20,13 @@
  *    Lauris Kaplinski <lauris@ximian.com>
  *
  *  Copyright (C) 2000-2001 Ximian Inc. and authors
- *
  */
 
-#define __GNOME_RFONT_C__
-
-#include "config.h"
+#include <config.h>
 #include <math.h>
 #include <string.h>
 #include <ctype.h>
+
 #include <freetype/freetype.h>
 #include <freetype/ftglyph.h>
 #include <freetype/ftbbox.h>
@@ -43,8 +41,8 @@
 #include <libart_lgpl/art_gray_svp.h>
 #include <libart_lgpl/art_rgb_svp.h>
 #include <libart_lgpl/art_svp_wind.h>
-#include "gnome-font-private.h"
-#include "gnome-rfont.h"
+#include <libgnomeprint/gnome-font-private.h>
+#include <libgnomeprint/gnome-rfont.h>
 
 #define noGRF_VERBOSE
 #define noGRF_DEBUG
@@ -226,6 +224,18 @@ gnome_rfont_finalize (GObject * object)
 #define PRINT_AFFINE(s,a)
 #endif
 
+/**
+ * gnome_font_get_rfont:
+ * @font: 
+ * @t: 
+ * 
+ * Creates a new RFont from @font and font->raster affine matrix
+ * Matrix can be 2x2, although if read, all 2x3 values are
+ * retrieved. RFont is referenced, so you have to unref it
+ * somewhere
+ * 
+ * Return Value: the font created, NULL on error.
+ **/
 GnomeRFont *
 gnome_font_get_rfont (GnomeFont * font, const gdouble *t)
 {
