@@ -230,9 +230,7 @@ gpa_option_create_key (GPAOption *option, GPANode *parent)
 	GPAKey *key;
 
 	key = NULL;
-#if 0
-	g_print ("create key for:%s type:%d\n", GPA_NODE_ID (option), option->type);
-#endif
+
 	switch (option->type) {
 	case GPA_OPTION_TYPE_NODE:
 	case GPA_OPTION_TYPE_KEY:
@@ -529,7 +527,9 @@ gpa_option_list_new_from_tree (xmlNodePtr tree, GPANode *parent, const guchar *i
 	if (!has_default) {
 		g_warning ("Invalid default value in %s, default was set to "
 			   "\"%s\" but could not be found", id, def);
-//		gpa_node_unref (option);
+#if 0	
+		gpa_node_unref (option);
+#endif
 		option = NULL;
 	}
 
