@@ -17,9 +17,10 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *  Authors:
+ *    Chema Celorio <chema@ximian.com>
  *    Tambet Ingo <tambet@ximian.com>
  *
- *  Copyright (C) 2002 Ximian Inc. and authors
+ *  Copyright (C) 2002-2003 Ximian Inc.
  *
  */
 
@@ -27,6 +28,7 @@
 #include <stdio.h>
 #include <glib.h>
 #include <string.h>
+#include <signal.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprint/gnome-font.h>
@@ -66,7 +68,6 @@ static void
 print_font_info (GPFontEntry *entry, GnomePrintContext *gpc)
 {
 	GnomeFont *font;
-	GPFontEntryTT *tt = (GPFontEntryTT *) entry;
 	gdouble x, y, row_size;
 	gchar *c;
 
@@ -88,9 +89,6 @@ print_font_info (GPFontEntry *entry, GnomePrintContext *gpc)
 	gnome_print_show (gpc, "Name:");
 	y -= row_size;
 	gnome_print_moveto (gpc, x, y);
-	gnome_print_show (gpc, "Version:");
-	y -= row_size;
-	gnome_print_moveto (gpc, x, y);
 	gnome_print_show (gpc, "Family Name:");
 	y -= row_size;
 	gnome_print_moveto (gpc, x, y);
@@ -115,15 +113,12 @@ print_font_info (GPFontEntry *entry, GnomePrintContext *gpc)
 	y = 780;
 	x = x + 100;
 
-	c = g_strdup_printf ("%g", entry->ItalicAngle);
+	c = g_strdup_printf ("%d", entry->italic_angle);
 	
 	gnome_print_moveto (gpc, x, y);
 	gnome_print_show (gpc, entry->name);
 	y -= row_size;
 	gnome_print_moveto (gpc, x, y);
-	gnome_print_show (gpc, entry->version);
-	y -= row_size;
-	gnome_print_moveto (gpc, x, y);
 	gnome_print_show (gpc, entry->familyname);
 	y -= row_size;
 	gnome_print_moveto (gpc, x, y);
@@ -139,10 +134,18 @@ print_font_info (GPFontEntry *entry, GnomePrintContext *gpc)
 	gnome_print_show (gpc, c);
 	y -= row_size;
 	gnome_print_moveto (gpc, x, y);
-	gnome_print_show (gpc, "TrueType");
+
+	if (entry->type == GP_FONT_ENTRY_TRUETYPE) {
+		gnome_print_show (gpc, "TrueType");
+	} else if (entry->type == GP_FONT_ENTRY_TYPE1) {
+		gnome_print_show (gpc, "Type1");
+	} else {
+		gnome_print_show (gpc, "Unknown");
+	}
+	
 	y -= row_size;
 	gnome_print_moveto (gpc, x, y);
-	gnome_print_show (gpc, tt->ttf.name);
+	gnome_print_show (gpc, entry->file);
 	y -= row_size;
 
 	g_free (c);
@@ -157,9 +160,13 @@ static gint
 number_of_fonts (void)
 {
 	GPFontMap *map;
+	gint num;
 
 	map = gp_fontmap_get ();
-	return g_slist_length (map->fonts);
+	num = g_slist_length (map->fonts);
+	gp_fontmap_release (map);
+
+	return num;
 }
       
 
@@ -184,13 +191,6 @@ generate_font_info (gint num)
 
 	g_assert (entry);
 	
-	g_print ("Name: %s\n", entry->psname);
-	
-	if (entry->type != GP_FONT_ENTRY_TRUETYPE) {
-		g_print ("Only TrueType fonts are supported for now\n");
-		return;
-	}
-
 	job = gnome_print_job_new (NULL);
 	gpc = gnome_print_job_get_context (job);
 	config = gnome_print_job_get_config (job);
@@ -207,6 +207,7 @@ generate_font_info (gint num)
 	if (!gnome_print_config_set (config, GNOME_PRINT_KEY_OUTPUT_FILENAME,
 				     options_output ? options_output : (options_pdf ? "output.pdf" : "output.ps")))
 		g_print ("Could not set the output filename\n");
+	g_print ("options output:%s\n", options_output);
 	if (!gnome_print_config_set (config, GNOME_PRINT_KEY_OUTPUT_FILENAME,
 				     options_output ? options_output : "output.ps"))
 		g_print ("Could not set the output filename\n");
@@ -225,6 +226,34 @@ generate_catalog (void)
 	g_print ("Implement me\n");
 }
 
+static void
+dump_font_info (GPFontEntry *entry, gint num)
+{
+	g_print ("\n\nEntry:\t\t%d\n", num);
+	g_print ("Name:\t\t%s\n",       entry->name);
+	g_print ("Family Name:\t%s\n",  entry->familyname);
+	g_print ("Speciesname:\t%s\n",  entry->speciesname);
+	g_print ("PS name:\t%s\n",      entry->psname);
+	g_print ("Weight:\t\t%s\n",     entry->weight);
+	g_print ("Italic Angle:\t%d\n", entry->italic_angle);
+
+	switch (entry->type) {
+	case GP_FONT_ENTRY_UNKNOWN:
+		g_print ("Type:\t\tUnknown\n");
+		break;
+	case GP_FONT_ENTRY_TYPE1:
+		g_print ("Type:\t\tType 1\n");
+		break;
+	case GP_FONT_ENTRY_TRUETYPE:
+		g_print ("Type:\t\tTrue Type\n");
+		break;
+	case GP_FONT_ENTRY_ALIAS:
+		g_print ("Type:\t\tAlias\n");
+		break;
+	}
+	g_print ("File:\t\t%s\n", entry->file);
+}
+
 static void
 dump_short_list (void)
 {
@@ -243,45 +272,6 @@ dump_short_list (void)
 	gnome_font_list_free (list);
 }
 
-static void
-dump_font_info (GPFontEntry *entry, gint num)
-{
-	GPFontEntryTT *tt;
-	
-	g_print ("\n\nEntry:\t\t%d\n", num);
-	g_print ("Name:\t\t%s\n", entry->name);
-	g_print ("Version:\t%s\n", entry->version);
-	g_print ("Family Name:\t%s\n", entry->familyname);
-	g_print ("Speciesname:\t%s\n", entry->speciesname);
-	g_print ("PS name:\t%s\n", entry->psname);
-	g_print ("Weight:\t\t%s\n", entry->weight);
-	g_print ("Italic Angle:\t%g\n", entry->ItalicAngle);
-
-	switch (entry->type) {
-	case GP_FONT_ENTRY_UNKNOWN:
-		g_print ("Type:\t\tUnknown\n");
-		break;
-	case GP_FONT_ENTRY_TYPE1:
-		g_print ("Type:\t\tType 1\n");
-		break;
-	case GP_FONT_ENTRY_TRUETYPE:
-		tt = (GPFontEntryTT *) entry;
-		g_print ("Type:\t\tTrue Type\n");
-		g_print ("File:\t\t%s\n", tt->ttf.name);
-		g_print ("Face num:\t%d\n", tt->facenum);
-		break;
-	case GP_FONT_ENTRY_TYPE1_ALIAS:
-		g_print ("Type:\t\tType1 Alias\n");
-		break;
-	case GP_FONT_ENTRY_ALIAS:
-		g_print ("Type:\t\tAlias\n");
-		break;
-	case GP_FONT_ENTRY_SPECIAL:
-		g_print ("Type:\t\tSpecial\n");
-		break;
-	}
-}
-
 static void
 dump_long_list (void)
 {
@@ -299,6 +289,8 @@ dump_long_list (void)
 	}
 
 	g_slist_free (list);
+
+	g_print ("\n");
 }
 
 static void
@@ -342,9 +334,6 @@ check_options (int argc, const char *argv[])
 
 	popt = poptGetContext ("test", argc, argv, options, 0);
 	retval = poptGetNextOpt (popt);
-	/*
-	g_print ("Ret:%d\n", retval);
-	*/
 
 	if (options_dump)
 		num++;
@@ -387,9 +376,23 @@ check_options (int argc, const char *argv[])
 	exit (1);
 }
 
+static void
+handle_sigsegv (int i)
+{
+	g_print ("\n./fonts crashed \n");
+	exit (-5);
+}
+
 int
 main (int argc, const char *argv[])
 {
+	struct sigaction sig;
+
+	/* Catch SIGSEGV signals */
+	sig.sa_handler = handle_sigsegv;
+	sig.sa_flags = 0;
+	sigaction (SIGSEGV, &sig, NULL);
+	
 	check_options (argc, argv);
 
 	g_type_init ();
